==> ejc-ztpccom-api-3.0.0-20230715.090459-37-sources.jar: com/ejianc/business/ztpc/billcode/bean/GenerateBillCodeSNVO.java <==
package com.ejianc.business.ztpc.billcode.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 取号编码规则
 * 
 * @author generator
 * 
 */
public class GenerateBillCodeSNVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目id
    private Long categoryId; // 文档分类主键Id
    private String ruleType; // 规则类型，0内部编码，1外部编码

    private Long ruleId; // 主表id
    private String isInit; // 是否初始化(0：是，1：否)
    private String currSn; // 当前流水号
    private Integer startSn; // 起始流水号
    private Long sourcePid; // 来源单据主表id
    private String sourceCode; // 来源单据编码
    private String sourceType; // 来源单据类型
    private String generateBillCode; // 序列化编码

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getRuleType() {
        return ruleType;
    }

    public void setRuleType(String ruleType) {
        this.ruleType = ruleType;
    }

    public Long getRuleId() {
        return ruleId;
    }

    public void setRuleId(Long ruleId) {
        this.ruleId = ruleId;
    }

    public String getIsInit() {
        return isInit;
    }

    public void setIsInit(String isInit) {
        this.isInit = isInit;
    }

    public String getCurrSn() {
        return currSn;
    }

    public void setCurrSn(String currSn) {
        this.currSn = currSn;
    }

    public Integer getStartSn() {
        return startSn;
    }

    public void setStartSn(Integer startSn) {
        this.startSn = startSn;
    }

    public Long getSourcePid() {
        return sourcePid;
    }

    public void setSourcePid(Long sourcePid) {
        this.sourcePid = sourcePid;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getGenerateBillCode() {
        return generateBillCode;
    }

    public void setGenerateBillCode(String generateBillCode) {
        this.generateBillCode = generateBillCode;
    }
}

==> ejc-ztpccom-api-3.0.0-20230717.151219-57-sources.jar: com/ejianc/business/ztpc/billcode/bean/GenerateBillCodeSNVO.java <==
package com.ejianc.business.ztpc.billcode.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 取号编码规则
 * 
 * @author generator
 * 
 */
public class GenerateBillCodeSNVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目id
    private Long categoryId; // 文档分类主键Id
    private String ruleType; // 规则类型，0内部编码，1外部编码

    private Long ruleId; // 主表id
    private String isInit; // 是否初始化(0：是，1：否)
    private String currSn; // 当前流水号
    private Integer startSn; // 起始流水号
    private Long sourcePid; // 来源单据主表id
    private String sourceCode; // 来源单据编码
    private String sourceType; // 来源单据类型
    private String sourceTypeName; // 来源单据类型名称
    private String generateBillCode; // 序列化编码

    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private String rule05; // 专业字段对应的code，对应数据字典档案编码
    private String rule06; // 预留字段
    private String rule07; // 预留字段
    private String rule08; // 预留字段
    private String rule09; // 预留字段

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getRuleType() {
        return ruleType;
    }

    public void setRuleType(String ruleType) {
        this.ruleType = ruleType;
    }

    public Long getRuleId() {
        return ruleId;
    }

    public void setRuleId(Long ruleId) {
        this.ruleId = ruleId;
    }

    public String getIsInit() {
        return isInit;
    }

    public void setIsInit(String isInit) {
        this.isInit = isInit;
    }

    public String getCurrSn() {
        return currSn;
    }

    public void setCurrSn(String currSn) {
        this.currSn = currSn;
    }

    public Integer getStartSn() {
        return startSn;
    }

    public void setStartSn(Integer startSn) {
        this.startSn = startSn;
    }

    public Long getSourcePid() {
        return sourcePid;
    }

    public void setSourcePid(Long sourcePid) {
        this.sourcePid = sourcePid;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getGenerateBillCode() {
        return generateBillCode;
    }

    public void setGenerateBillCode(String generateBillCode) {
        this.generateBillCode = generateBillCode;
    }

    public String getSourceTypeName() {
        return sourceTypeName;
    }

    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getRule05() {
        return rule05;
    }

    public void setRule05(String rule05) {
        this.rule05 = rule05;
    }

    public String getRule06() {
        return rule06;
    }

    public void setRule06(String rule06) {
        this.rule06 = rule06;
    }

    public String getRule07() {
        return rule07;
    }

    public void setRule07(String rule07) {
        this.rule07 = rule07;
    }

    public String getRule08() {
        return rule08;
    }

    public void setRule08(String rule08) {
        this.rule08 = rule08;
    }

    public String getRule09() {
        return rule09;
    }

    public void setRule09(String rule09) {
        this.rule09 = rule09;
    }
}
